@@ -57,11 +57,11 @@ ggplot_heatmap <- function(xx,
                            type = c("heatmap", "scatter"),
                            pointsize = 5,
                            point_size_mat = NULL,
-                           label_format_fun = function(...) format(..., digits = 4),
                            point_size_name = "Point size",
+                           label_format_fun = function(...) format(..., digits = 4),
                            custom_hovertext = NULL,
+                           showticklabels = c(TRUE, TRUE),
                            ...) {
-
   theme_clear_grid_heatmap <- theme(
     axis.line = element_line(color = "black"),
     panel.grid.major = element_blank(),
@@ -151,17 +151,15 @@ ggplot_heatmap <- function(xx,
     theme_bw() +
     theme_clear_grid_heatmap +
     theme(
-      axis.text.x = element_text(
-        angle = column_text_angle,
-        size = fontsize_col, 
-        hjust = 1
-      ),
-      axis.text.y = element_text(
-        angle = row_text_angle,
-        size = fontsize_row, 
-        hjust = 1
-      ),
-      axis.title = element_blank()
+      axis.title = element_blank(),
+      axis.text.x = if (showticklabels[[1]]) {
+        element_text(angle = column_text_angle, size = fontsize_col, hjust = 1)
+      } else element_blank(),
+      axis.ticks.x = if (showticklabels[[1]]) element_line() else element_blank(),
+      axis.text.y = if (showticklabels[[2]]) {
+        element_text(angle = row_text_angle, size = fontsize_row, hjust = 1)
+      } else element_blank(),
+      axis.ticks.y = if (showticklabels[[2]]) element_line() else element_blank(),
     )
 
   if (type == "scatter") {
@@ -227,21 +225,24 @@ paste_aes <- function(x) {
 plotly_heatmap <- function(x,
                            limits = range(x),
                            colors = viridis(n = 256, alpha = 1, begin = 0, end = 1, option = "viridis"),
-                           row_text_angle = 0, 
-                           column_text_angle = 45, 
-                           grid.color, 
+                           row_text_angle = 0,
+                           column_text_angle = 45,
+                           grid.color,
                            grid.size,
-                           row_dend_left = FALSE, 
+                           row_dend_left = FALSE,
                            fontsize_row = 10,
-                           fontsize_col = 10, 
+                           fontsize_col = 10,
                            key_title = "",
-                           colorbar_xanchor = "left", 
+                           colorbar_xanchor = "left",
                            colorbar_yanchor = "bottom",
                            label_names = NULL,
-                           colorbar_xpos = 1.1, 
-                           colorbar_ypos = 1, 
+                           colorbar_xpos = 1.1,
+                           colorbar_ypos = 1,
                            colorbar_len = 0.3,
+                           colorbar_thickness = 30,
                            custom_hovertext = NULL,
+                           point_size_mat = NULL,
+                           point_size_name = "Point size",
                            showticklabels = c(TRUE, TRUE)) {
 
   if (is.function(colors)) colors <- colors(256)
@@ -256,26 +257,60 @@ plotly_heatmap <- function(x,
     assert_that(length(label_names) == 3)
   }
 
-  text_mat <- as.data.frame(x)
-  text_mat[] <- lapply(
-    seq_along(text_mat),
-    function(i) {
-      paste0(
-        label_names[3], ": ", x[, i], "<br>",
-        label_names[2], ": ", colnames(x)[i], "<br>",
-        label_names[1], ": ", rownames(x)
-      )
-    }
-  )
-  text_mat <- as.matrix(text_mat)
   if (!is.null(custom_hovertext)) {
-    text_mat[] <- paste(text_mat, custom_hovertext, sep = "<br>")
+    text_mat <- custom_hovertext
+  } else {
+    text_mat <- as.data.frame(x)
+    text_mat[] <- lapply(
+      seq_along(text_mat),
+      function(i) {
+        paste0(
+          label_names[3], ": ", x[, i], "<br>",
+          label_names[2], ": ", colnames(x)[i], "<br>",
+          label_names[1], ": ", rownames(x)
+        )
+      }
+    )
+    text_mat <- as.matrix(text_mat)
+    if (!is.null(point_size_mat)) {
+      point_size_name
+    }
   }
-  p <- plot_ly(
-    z = x, x = 1:ncol(x), y = 1:nrow(x), text = text_mat,
-    type = "heatmap", showlegend = FALSE, colors = colors, hoverinfo = "text",
-    zmin = limits[1], zmax = limits[2]
-  ) %>%
+
+  if (is.null(point_size_mat)) {
+    p <- plot_ly(
+      z = x, x = 1:ncol(x), y = 1:nrow(x), text = text_mat,
+      type = "heatmap",
+      showlegend = FALSE,
+      colors = colors,
+      hoverinfo = "text",
+      zmin = limits[1], zmax = limits[2]
+    )    
+  } else {
+    melt <- function(x, cn, rn) {
+      xdf <- reshape2::melt(x)
+      xdf$Var1 <- factor(xdf$Var1, levels = colnames(x))
+      xdf$Var2 <- factor(xdf$Var2, levels = rownames(x))
+      xdf
+    }
+    xdf <- melt(x)
+    tdf <- melt(text_mat)
+    pdf <- melt(point_size_mat)
+    
+    p <- plot_ly(
+      x = as.numeric(xdf$Var1),
+      y = as.numeric(xdf$Var2),
+      text = tdf$value,
+      color = xdf$value,
+      size = pdf$value,
+      type = "scatter",
+      mode = "markers",
+      showlegend = FALSE,
+      colors = colors,
+      hoverinfo = "text"
+    )
+  }
+  p <- p  %>%
     layout(
       xaxis = list(
         tickfont = list(size = fontsize_col),
@@ -295,16 +330,22 @@ plotly_heatmap <- function(x,
       )
     )
   p <- plotly::colorbar(
-    p, lenmode = "fraction", title = key_title,
-    xanchor = colorbar_xanchor, x = colorbar_xpos, y = colorbar_ypos,
-    yanchor = colorbar_yanchor, len = colorbar_len
+    p,
+    lenmode = "fraction",
+    title = key_title,
+    xanchor = colorbar_xanchor,
+    x = colorbar_xpos,
+    y = colorbar_ypos,
+    yanchor = colorbar_yanchor,
+    len = colorbar_len,
+    thickness = colorbar_thickness
   )
   p
 }
 
 
-plotly_dend <- function(dend, 
-                        side = c("row", "col"), 
+plotly_dend <- function(dend,
+                        side = c("row", "col"),
                         flip = FALSE,
                         dend_hoverinfo = TRUE) {
 
@@ -409,12 +450,12 @@ plotly_dend <- function(dend,
 #'
 #' @return A ggplot geom_tile object
 #'
-ggplot_side_color_plot <- function(df, 
+ggplot_side_color_plot <- function(df,
                                    palette = NULL,
-                                   scale_title = paste(type, "side colors"), 
+                                   scale_title = paste(type, "side colors"),
                                    type = c("column", "row"),
-                                   text_angle = if (type == "column") 0 else 90, 
-                                   is_colors = FALSE, 
+                                   text_angle = if (type == "column") 0 else 90,
+                                   is_colors = FALSE,
                                    fontsize = 10,
                                    label_name = NULL) {
 
@@ -471,6 +512,10 @@ ggplot_side_color_plot <- function(df,
   }
   theme <- list(common_theme, specific_theme)
 
+  if (is_colors) {
+    palette <- setNames(unique(df[["value"]]), unique(df[["value"]]))
+  }
+
   if (is.function(palette)) {
     palette <- setNames(palette(nlevels(df[["value"]])), levels(df[["value"]]))
   } else if (!all(levels(factor(df[["value"]])) %in% names(palette))) {
@@ -487,7 +532,7 @@ ggplot_side_color_plot <- function(df,
     scale_fill_manual(
       name = scale_title,
       breaks = levels(df[["value"]]),
-      values = palette[levels(df[["value"]])]
+      values = as.character(palette[levels(df[["value"]])])
     ) +
     theme
   return(g)
@@ -519,15 +564,27 @@ default_side_colors <- function(n) {
 
 ## Predict luminosity of cells and change text based on that
 ## http://stackoverflow.com/questions/12043187/how-to-check-if-hex-color-is-too-black
-predict_colors <- function(p, 
-                           colorscale_df = p$x$data[[1]]$colorscale,
-                           cell_values = p$x$data[[1]]$z, 
+predict_colors <- function(p,
+                           colorscale_df = p$x$data[[1]]$colorscale %||% p$x$data[[2]]$marker$colorscale,
+                           cell_values = p$x$data[[1]]$z,
                            plot_method = c("ggplot", "plotly")) {
 
   plot_method <- match.arg(plot_method)
 
+  if (is.null(cell_values)) {
+    cell_values <- as.data.frame(
+      matrix(
+        p$x$data[[1]]$marker$size,
+        ncol = length(unique(p$x$data[[1]]$x)),
+        nrow = length(unique(p$x$data[[1]]$y))
+      )
+    )
+  }
+  if (is.null(colorscale_df)) {
+    stop("Internal error in predicting colours!")
+  }
   cell_values <- as.data.frame(cell_values)
-  cell_values$row <- 1:nrow(cell_values)
+  cell_values$row <- seq_len(nrow(cell_values))
   cell_values_m <- reshape2::melt(cell_values, id.vars = "row")
   cell_values_vector <- cell_values_m$value
 
@@ -616,11 +673,11 @@ discrete_colorscale <- function(colors) {
 }
 
 #' @importFrom stats setNames
-plotly_side_color_plot <- function(df, 
+plotly_side_color_plot <- function(df,
                                    palette = NULL,
-                                   scale_title = paste(type, "side colors"), 
+                                   scale_title = paste(type, "side colors"),
                                    type = c("column", "row"),
-                                   text_angle = if (type == "column") 0 else 90, 
+                                   text_angle = if (type == "column") 0 else 90,
                                    is_colors = FALSE,
                                    label_name = NULL,
                                    colorbar_len = 0.3,
@@ -838,8 +895,8 @@ hmly_to_file <- Vectorize(hmly_to_file_1file, vectorize.args = "file")
 #' @importFrom grDevices col2rgb
 col2hex <- function(col) {
     colMat <- col2rgb(col)
-    rgb(red = colMat[1, ] / 255, 
-        green = colMat[2, ] / 255, 
+    rgb(red = colMat[1, ] / 255,
+        green = colMat[2, ] / 255,
         blue = colMat[3, ] / 255)
 }
 
